---
title: Spree 3.7.0
section: release_notes
order: 1
---

## Major/New Features

3.7 release is our last 3.x line release bridging the gap between 3.x and Spree 4.0. This is a big release packed with several amazing features and a huge number of bug fixes ([over 700 commits by 17 contributors](https://github.com/spree/spree/compare/3-6-stable...3-7-stable)!). Upgrading to 3.7 guarantees a smooth and easy migration to [Spree 4.0](https://github.com/spree/spree/milestone/37) (April 2019 with Rails 6.0 support).

**Spree 3.7** requires **Rails 5.2.2** and **Ruby 2.3.3** (or higher).

### [Storefront API v2](/api/v2/storefront)

We've worked hard over the last few months to deliver a completely new, easy to work with and lightweight REST API for building amazing customer interfaces with modern JavaScript libraries (React, Vue, Angular) and for native mobile apps. New Storefront API v2 is fast, easy to use and extend. It's also well documented in [OpenAPI 3.0 (Swagger) format](https://raw.githubusercontent.com/spree/spree/master/api/docs/v2/storefront/index.yaml) which you can [import into Postman app](http://blog.getpostman.com/2018/12/11/postman-supports-openapi-3-0/).

New API is based on [JSON API](https://jsonapi.org/) spec and uses blazing fast Netflix [fast_json_api](https://github.com/Netflix/fast_jsonapi) serializer library. [Authentication](/api/v2/authentication) is based on Oauth using [doorkeeper](https://github.com/doorkeeper-gem/doorkeeper) library. Besides that there are no additional dependencies making it lightweight and future-proof.

Storefront API v2 consists of:

- [Cart endpoints](/api/v2/storefront#tag/Cart) (Create Cart, Add Item, Set Quantity, Remove Item, Empty Cart)
- [Checkout endpoints](/api/v2/storefront#tag/Checkout) (Update Checkout, Advance Checkout, Complete Checkout, Get Shiping Rates, Get Payment Methods)
- [Products](/api/v2/storefront/#tag/Products) Catalog
- [Taxons](/api/v2/storefront/#tag/Taxons) Catalog
- [Account](/api/v2/storefront#tag/Account) (Account Information, Credit Cards)
- [Countries](/api/v2/storefront/#tag/Countries)
- [Authentication](/api/v2/authentication)

All of the endpoints support JSON API's [Sparse Fieldsets](https://jsonapi.org/format/#fetching-sparse-fieldsets) to fix usual Over-Fetching issues and [Related Resources](https://jsonapi.org/format/#fetching-includes) to reduce the number of API queries you need to perform.

### Service Oriented Architecture

While building the API v2 we've also refactored a huge portion of Spree internals by introducing modular Service Oriented Architecture to the codebase.

We're in the process of moving domain-specific code from models to `Service Objects` with a well-defined scope and predictable return values. All service objects include [Service Module](https://github.com/spree/spree/blob/master/core/lib/spree/service_module.rb) which unifies how those classes handle arguments and what they return.

Also, we're moving away from ransack library by introducing `Finders` and `Sorters` classes for simpler fetching resources and collections.

This makes Spree codebase easier to read and learn. It also makes any customizations way easier. At the same time, public APIs won't change a lot as providing backward compatibility is one of our top priorities.

### Dependencies system

We're introducing a new painless way of customizing Spree without the need of decorators. With Dependencies you can easily replace parts of Spree internals with your custom classes. You can replace Services, Abilities and Serializers. More will come in the future. We hope using Dependencies will remove the need for creating decorators at all!

[See Documentation](/developer/customization/dependencies.html)

### Removing Coffee Script

CoffeeScript a few years back ago was a really great JavaScript enhancement. Nowadays with ES6 and TypeScript around it became obsolete. That's why we've converted all of the CoffeeScript assets in Spree and extensions to plain JavaScript and removed CoffeeScript dependency.

### Improved MySQL support

A lot of merchants were using Spree with MySQL for years now, but development of the platform was mainly focused on PostgreSQL support. We've changed that and all of our CI builds are tested and verified against both PostgreSQL and MySQL. We've also fixed all MySQL-related bugs.

## Installation

### Add Spree gems to Gemfile

```ruby
gem 'spree', '~> 3.7.0'
gem 'spree_auth_devise', '~> 3.5'
gem 'spree_gateway', '~> 3.4'
```

### Run `bundle install`

### Use the install generators to set up Spree

```shell
rails g spree:install --user_class=Spree::User
rails g spree:auth:install
rails g spree_gateway:install
```

## Upgrade

[Official Spree 3.6 to 3.7 upgrade guide](/developer/upgrades/three-dot-six-to-three-dot-seven)

## Noteworthy changes

Please review each of the noteworthy changes to ensure your customizations or extensions are not affected. If you are affected by a change, and have any suggestions please submit a PR to help the next person!

- Dropped support for Ruby 2.2

  [Spark Solutions](https://github.com/spree/spree/pull/8866)

- Support multiple currencies for `Store Credits` management in Admin Panel

  [Spark Solutions](https://github.com/spree/spree/pull/8912)

- Added information if Product is backorderable on Product page

  [Spark Solutions](https://github.com/spree/spree/pull/8438)

- Improved OmniChannel support in the Admin Panel

  [Spark Solutions](https://github.com/spree/spree/pull/8892)

- Improved error handling for XHR requests in the Admin Panel

  [Vernon de Goede](https://github.com/spree/spree/pull/9089)

- Improved Admin Panel Variant autocomplete

  [Spark Solutions](https://github.com/spree/spree/pull/8780)

- `Order` is now associated with `Store`, the presence of `Store` is required for validation

  [Spark Solutions](https://github.com/spree/spree/pull/8926)

- `Order` now has to have `currency` value set

  [Spark Solutions](https://github.com/spree/spree/pull/8927)

- Made `CreditCard` deleted softly by default

  [Spark Solutions](https://github.com/spree/spree/pull/9054)

- Payment `source` needs to be present (validation can be turned off via `source_required?` in `PaymentMethod`)

  [Spark Solutions](https://github.com/spree/spree/pull/9054)

- Added `StockLocation#name` unique validation

  [himanshumishra31](https://github.com/spree/spree/pull/8804)

- Added `FulfilmentChanger` class

  [Spark Solutions](https://github.com/spree/spree/pull/8725)

- Extended `OrderPromotion` model

  [Spark Solutions](https://github.com/spree/spree/pull/9126/commits/cdbcef82c3b90a9b07d107f7eb9cbea04dbe7266)

- Added `ShippingRate#final_price` method

  [Spark Solutions](https://github.com/spree/spree/commit/b55ac6e01f3cba9c4b7f4409de767646ff5f7bf7#diff-f679c11eac90d5fa687247a06a0de8db)

- Added `Shipment#free?` method

  [Spark Solutions](https://github.com/spree/spree/commit/5efa747f66c07beab6742d3b41e721c7727a435d#diff-f679c11eac90d5fa687247a06a0de8db)

- Added `Product#default_variant` and `Product#default_variant_id` methods

  [Spark Solutions](https://github.com/spree/spree/commit/0ec65dba11ccd969efd3944c76f3befb5a8fbcaa#diff-f679c11eac90d5fa687247a06a0de8db)

- Delegated `iso` and `iso_name` in `Address` model to `Country`

  [Spark Solutions](https://github.com/spree/spree/pull/9173/commits/f4405e8c3999bb844287b55617a3f318d31edb7f)

- Replaced `jquery.cookie` with `js.cookie`

  [Spark Solutions](https://github.com/spree/spree/pull/8758)

- Fixed deprecation warning: `BigDecimal.new() is deprecated`

  [Deepak Mahakale](https://github.com/spree/spree/pull/8897)

- Fixed displaying currency in `Admin Panel` -> `Return Authorizations`

  [Spark Solutions](https://github.com/spree/spree/pull/9005)

- Fixed all deprecations of Ruby Money 6.13+

  [Spark Solutions](https://github.com/spree/spree/pull/9036)

- Fallback to `Order#currency` if there's no currency set for `Adjustment`

  [Spark Solutions](https://github.com/spree/spree/commit/04d4c94d30feb770ff4b14db8d7a597888535676#diff-f679c11eac90d5fa687247a06a0de8db)

- Renamed `Order#guest_token` to `Order#token`

  [Spark Solutions](https://github.com/spree/spree/pull/8826)

- Renamed `Admin::GeneralSettingsHelper` to `Admin::CurrencyHelper`

  [Spark Solutions](https://github.com/spree/spree/pull/8912)

- Renamed `TaxonIcon` to `TaxonImage`

  [Spark Solutions](https://github.com/spree/spree/pull/8879)

- Deprecated `OrderContents` and replaced with several `Cart` services (eg. `Cart::AddItem`)

  [Spark Solutions](https://github.com/spree/spree/pull/8732/commits/f86b4c2c4d3fb468038bfb99389490be73ba998c)

- Deprecated `Order#add_store_credit_payments` in favor of `Checkout::AddStoreCredit` service

  [Spark Solutions](https://github.com/spree/spree/pull/9146)

- Deprecated `Order#remove_store_credit_payments` in favor of `Checkout::RemoveStoreCredit` service

  [Spark Solutions](https://github.com/spree/spree/pull/9152)

- Deprecated `OrdersController#populate` and `OrdersController#populate_redirect`

  [Spark Solutions](https://github.com/spree/spree/pull/9050/commits/215cb4391c574136f87824771e14ab211d6cf59c)

- Deprecated `Address#same_as?` in favor of `Address#==`

  [Spark Solutions](https://github.com/spree/spree/pull/8386)

- Deprecated `Order#add register_line_item_comparison_hook` (please use `Rails.application.config.spree.line_item_comparison_hooks << hook` instead)

  [Spark Solutions](https://github.com/spree/spree/commit/0a525ccab9ea0bc52cc4e249d53b38df6f231691)

- Deprecated `ControllerHelpers::RespondWith`

  [Spark Solutions](https://github.com/spree/spree/pull/9081)

- Deprecated `BaseHelper#variant_options`

  [Spark Solutions](https://github.com/spree/spree/pull/9105)

- Deprecated `Address#iso_name`, please use `Address#country_iso_name`

  [Spark Solutions](https://github.com/spree/spree/pull/9173)

- Removed previously deprecated `Spree::Core::EnvironmentExtension`

  [Spark Solutions](https://github.com/spree/spree/pull/8782)

- Removed previously deprecated `ControllerHelpers::Common#render_404`

  [Spark Solutions](https://github.com/spree/spree/pull/8782)

- Removed previously deprecated `EmailValidator`

  [Spark Solutions](https://github.com/spree/spree/pull/9029)

- Removed previously deprecated `NavigationHelper#icon`

  [Spark Solutions](https://github.com/spree/spree/pull/9121)

- Removed previously deprecated `FrontendHelper#breadcrums`

  [Spark Solutions](https://github.com/spree/spree/pull/9121)

- Removed `Product#distinct_by_product_ids`

  [Spark Solutions](https://github.com/spree/spree/commit/960b211026fbec0095f774b69c78dea64559a6c3#diff-f679c11eac90d5fa687247a06a0de8db)

- Bumped `highline` dependency to `2.0.x`

  [Chamnap Chhorn
  ](https://github.com/spree/spree/pull/9079)

- Bumped `paperclip` dependency to `6.1.x`

  [Josh Powell](https://github.com/spree/spree/pull/9028)

- Bumped `bootstrap-sass` to `3.4.x`

  [Spark Solutions](https://github.com/spree/spree/pull/9168)

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-6-stable...3-7-stable).
